@@ -52,10 +52,9 @@ NA
 #' @export
 #' @rdname gf_ash
 #' @examples
-#' gf_ash(~Sepal.Length, color = ~ Species, data = iris)
-#' gf_ash(~Sepal.Length, color = ~ Species, data = iris, binwidth = 0.3)
-#' gf_ash(~Sepal.Length, color = ~ Species, data = iris, adjust = 2)
-
+#' gf_ash(~Sepal.Length, color = ~Species, data = iris)
+#' gf_ash(~Sepal.Length, color = ~Species, data = iris, binwidth = 0.3)
+#' gf_ash(~Sepal.Length, color = ~Species, data = iris, adjust = 2)
 gf_ash <-
   layer_factory(
     geom = "line", stat = "ash", position = "identity",
@@ -76,18 +75,18 @@ gf_ash <-
 
 StatAsh <-
   ggproto("StatAsh", Stat,
-          compute_group = function(data, scales, binwidth = NULL, adjust = NULL) {
-            ash_points(data$x, binwidth = binwidth, adjust = adjust)
-          },
-          required_aes = c("x")
+    compute_group = function(data, scales, binwidth = NULL, adjust = NULL) {
+      ash_points(data$x, binwidth = binwidth, adjust = adjust)
+    },
+    required_aes = c("x")
   )
 
 #' @rdname gf_ash
 #' @export
 stat_ash <-
   function(mapping = NULL, data = NULL, geom = "line",
-           position = "identity", na.rm = FALSE, show.legend = NA,
-           inherit.aes = TRUE, binwidth = NULL, adjust = 1, ...) {
+             position = "identity", na.rm = FALSE, show.legend = NA,
+             inherit.aes = TRUE, binwidth = NULL, adjust = 1, ...) {
     ggplot2::layer(
       stat = StatAsh, data = data, mapping = mapping, geom = geom,
       position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -125,15 +124,16 @@ stat_ash <-
 #' @examples
 #' ggplot(faithful, aes(x = eruptions)) +
 #'   geom_histogram(aes(y = stat(density)),
-#'     fill = "lightskyblue", colour = "gray50", alpha = 0.2) +
+#'     fill = "lightskyblue", colour = "gray50", alpha = 0.2
+#'   ) +
 #'   geom_ash(colour = "red") +
 #'   geom_ash(colour = "forestgreen", adjust = 2) +
-#'   geom_ash(colour = "navy", adjust = 1/2) +
+#'   geom_ash(colour = "navy", adjust = 1 / 2) +
 #'   theme_minimal()
 geom_ash <-
   function(mapping = NULL, data = NULL, stat = "ash",
-           position = "identity", na.rm = FALSE, show.legend = NA,
-           inherit.aes = TRUE, binwidth = NULL, adjust = 1, ...) {
+             position = "identity", na.rm = FALSE, show.legend = NA,
+             inherit.aes = TRUE, binwidth = NULL, adjust = 1, ...) {
     ggplot2::layer(
       stat = stat, geom = ggplot2::GeomLine, data = data, mapping = mapping,
       position = position, show.legend = show.legend,
@@ -149,25 +149,29 @@ geom_ash <-
 #' @seealso [gf_spline()]
 StatSpline <-
   ggproto("StatSpline", Stat,
-          compute_group = function(data, scales, weight = NULL, df = NULL, spar = NULL,
-                                   cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
-                                   df.offset  = 0, penalty = 1,  control.spar = list(),
-                                   tol = NULL) {
-            if (is.null(tol)) tol <- 1e-6 * IQR(data$x)
-            SS <- if (is.null(df)) {
-              smooth.spline(data$x, data$y, w = weight, spar = spar,
-                            cv = cv, all.knots = all.knots, nknots = nknots,
-                            df.offset = df.offset, penalty = penalty, control.spar = control.spar,
-                            tol = tol)
-            } else {
-              smooth.spline(data$x, data$y, w = weight, df = df, spar = spar,
-                            cv = cv, all.knots = all.knots, nknots = nknots,
-                            df.offset = df.offset, penalty = penalty, control.spar = control.spar,
-                            tol = tol)
-            }
-            data_frame(x = SS$x, y = SS$y)
-          },
-          required_aes = c("x", "y")
+    compute_group = function(data, scales, weight = NULL, df = NULL, spar = NULL,
+                                 cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
+                                 df.offset = 0, penalty = 1, control.spar = list(),
+                                 tol = NULL) {
+      if (is.null(tol)) tol <- 1e-6 * IQR(data$x)
+      SS <- if (is.null(df)) {
+        smooth.spline(data$x, data$y,
+          w = weight, spar = spar,
+          cv = cv, all.knots = all.knots, nknots = nknots,
+          df.offset = df.offset, penalty = penalty, control.spar = control.spar,
+          tol = tol
+        )
+      } else {
+        smooth.spline(data$x, data$y,
+          w = weight, df = df, spar = spar,
+          cv = cv, all.knots = all.knots, nknots = nknots,
+          df.offset = df.offset, penalty = penalty, control.spar = control.spar,
+          tol = tol
+        )
+      }
+      tibble(x = SS$x, y = SS$y)
+    },
+    required_aes = c("x", "y")
   )
 
 #' Geoms and stats for spline smoothing
@@ -219,24 +223,25 @@ StatSpline <-
 #' @export
 #' @examples
 #' if (require(mosaicData)) {
-#'   ggplot(Births) + geom_spline(aes(x = date, y=births, colour = wday))
-#'   ggplot(Births) + geom_spline(aes(x = date, y=births, colour = wday), nknots = 10)
+#'   ggplot(Births) + geom_spline(aes(x = date, y = births, colour = wday))
+#'   ggplot(Births) + geom_spline(aes(x = date, y = births, colour = wday), nknots = 10)
 #' }
-#'
 stat_spline <-
   function(mapping = NULL, data = NULL, geom = "line",
-           position = "identity", na.rm = FALSE, show.legend = NA,
-           inherit.aes = TRUE, weight = NULL, df = NULL, spar = NULL,
-           cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
-           df.offset  = 0, penalty = 1,  control.spar = list(),
-           tol = NULL, ...) {
+             position = "identity", na.rm = FALSE, show.legend = NA,
+             inherit.aes = TRUE, weight = NULL, df = NULL, spar = NULL,
+             cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
+             df.offset = 0, penalty = 1, control.spar = list(),
+             tol = NULL, ...) {
     ggplot2::layer(
       stat = StatSpline, data = data, mapping = mapping, geom = geom,
       position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-      params = list(na.rm = na.rm, weight = weight, df = df, spar = spar,
-                    cv = cv, all.knots = all.knots, nknots = nknots,
-                    df.offset  = df.offset, penalty = penalty,
-                    control.spar = control.spar, tol = tol, ...)
+      params = list(
+        na.rm = na.rm, weight = weight, df = df, spar = spar,
+        cv = cv, all.knots = all.knots, nknots = nknots,
+        df.offset = df.offset, penalty = penalty,
+        control.spar = control.spar, tol = tol, ...
+      )
     )
   }
 
@@ -244,19 +249,21 @@ stat_spline <-
 #' @export
 geom_spline <-
   function(mapping = NULL, data = NULL, stat = "spline",
-           position = "identity", na.rm = FALSE, show.legend = NA,
-           inherit.aes = TRUE, weight = NULL, df = NULL, spar = NULL,
-           cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
-           df.offset  = 0, penalty = 1,  control.spar = list(),
-           tol = NULL, ...) {
+             position = "identity", na.rm = FALSE, show.legend = NA,
+             inherit.aes = TRUE, weight = NULL, df = NULL, spar = NULL,
+             cv = FALSE, all.knots = FALSE, nknots = stats::.nknots.smspl,
+             df.offset = 0, penalty = 1, control.spar = list(),
+             tol = NULL, ...) {
     ggplot2::layer(
       stat = stat, geom = ggplot2::GeomLine, data = data, mapping = mapping,
       position = position, show.legend = show.legend,
       inherit.aes = inherit.aes,
-      params = list(na.rm = na.rm, weight = weight, df = df, spar = spar,
-                    cv = cv, all.knots = all.knots, nknots = nknots,
-                    df.offset  = df.offset, penalty = penalty,
-                    control.spar = control.spar, tol = tol, ...)
+      params = list(
+        na.rm = na.rm, weight = weight, df = df, spar = spar,
+        cv = cv, all.knots = all.knots, nknots = nknots,
+        df.offset = df.offset, penalty = penalty,
+        control.spar = control.spar, tol = tol, ...
+      )
     )
   }
 
@@ -278,20 +285,20 @@ qq.line <- function(sample, qdist, na.rm = TRUE, tail = 0.25) {
 #' @seealso [stat_qq()]
 #' @seealso [gf_qq()]
 StatQqline <- ggproto("StatQqline", Stat,
-                      required_aes = c('sample'),
-                      compute_group = function(data, scales,
-                                               distribution = stats::qnorm,
-                                               dparams = list(),
-                                               tail = 0.25,
-                                               na.rm = FALSE) {
-                        qdist <- function(p) do.call(distribution, c(list(p = p), dparams))
+  required_aes = c("sample"),
+  compute_group = function(data, scales,
+                             distribution = stats::qnorm,
+                             dparams = list(),
+                             tail = 0.25,
+                             na.rm = FALSE) {
+    qdist <- function(p) do.call(distribution, c(list(p = p), dparams))
 
-                        n <- length(data$sample)
-                        theoretical <- qdist(stats::ppoints(n))
-                        qq <- qq.line(data$sample, qdist = qdist, tail = tail, na.rm = na.rm)
+    n <- length(data$sample)
+    theoretical <- qdist(stats::ppoints(n))
+    qq <- qq.line(data$sample, qdist = qdist, tail = tail, na.rm = na.rm)
 
-                        data.frame(x = theoretical, y = qq$intercept + theoretical * qq$slope)
-                      }
+    data.frame(x = theoretical, y = qq$intercept + theoretical * qq$slope)
+  }
 )
 
 #' A Stat for Adding Reference Lines to QQ-Plots
@@ -323,22 +330,25 @@ StatQqline <- ggproto("StatQqline", Stat,
 #' @examples
 #' ggplot(data = iris, aes(sample = Sepal.Length)) +
 #'   geom_qq() +
-#'   stat_qqline( alpha = 0.7, color = "red", linetype = "dashed") +
+#'   stat_qqline(alpha = 0.7, color = "red", linetype = "dashed") +
 #'   facet_wrap(~Species)
-
 stat_qqline <-
   function(mapping = NULL, data = NULL, geom = "line",
-           position = "identity", ...,
-           distribution = stats::qnorm,
-           dparams = list(),
-           na.rm = FALSE,
-           show.legend = NA,
-           inherit.aes = TRUE) {
-    layer(stat = StatQqline, data = data, mapping = mapping, geom = geom,
-          position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-          params = list(distribution = distribution,
-                        dparams = dparams,
-                        na.rm = na.rm, ...))
+             position = "identity", ...,
+             distribution = stats::qnorm,
+             dparams = list(),
+             na.rm = FALSE,
+             show.legend = NA,
+             inherit.aes = TRUE) {
+    layer(
+      stat = StatQqline, data = data, mapping = mapping, geom = geom,
+      position = position, show.legend = show.legend, inherit.aes = inherit.aes,
+      params = list(
+        distribution = distribution,
+        dparams = dparams,
+        na.rm = na.rm, ...
+      )
+    )
   }
 
 
@@ -347,23 +357,26 @@ stat_qqline <-
 #' @export
 stat_lm <-
   function(
-    mapping = NULL, data = NULL, geom = "lm",
-    position = "identity",
-    interval = c("none", "prediction", "confidence"),
-    level = 0.95,
-    formula = y ~ x, lm.args = list(), backtrans = identity,
-    ...,
-    na.rm = FALSE,
-    show.legend = NA,
-    inherit.aes = TRUE)  {
-
+             mapping = NULL, data = NULL, geom = "lm",
+             position = "identity",
+             interval = c("none", "prediction", "confidence"),
+             level = 0.95,
+             formula = y ~ x, lm.args = list(), backtrans = identity,
+             ...,
+             na.rm = FALSE,
+             show.legend = NA,
+             inherit.aes = TRUE) {
     interval <- match.arg(interval)
-    params <- list(interval = interval, level = level, formula = formula,
-                   lm.args = lm.args, na.rm = na.rm, backtrans = backtrans, ...)
+    params <- list(
+      interval = interval, level = level, formula = formula,
+      lm.args = lm.args, na.rm = na.rm, backtrans = backtrans, ...
+    )
 
-    layer(stat = StatLm, data = data, mapping = mapping, geom = geom,
-          position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-          params = params)
+    layer(
+      stat = StatLm, data = data, mapping = mapping, geom = geom,
+      position = position, show.legend = show.legend, inherit.aes = inherit.aes,
+      params = params
+    )
   }
 
 #' @rdname ggformula-ggproto
@@ -373,72 +386,71 @@ stat_lm <-
 #' @seealso [gf_lm()]
 StatLm <-
   ggproto("StatLm", Stat,
-          setup_params = function(data, params) {
-            if (identical(params$interval, "none")) {
-              params$se <- FALSE
+    setup_params = function(data, params) {
+      if (identical(params$interval, "none")) {
+        params$se <- FALSE
+      } else {
+        params$se <- TRUE
+      }
+      params
+    },
+    compute_group = function(data, scales, formula = y ~ x,
+                                 n = 80, span = 0.75, fullrange = TRUE,
+                                 xseq = NULL, level = 0.95, interval = "confidence",
+                                 lm.args = list(), na.rm = FALSE, se = NULL,
+                                 backtrans = identity) {
+      model <- NULL
+      interval <- match.arg(interval, c("none", "confidence", "prediction"))
+
+      # if no model provided, fit one
+      if (is.null(model)) {
+        # unless we don't have enough data
+        if (length(unique(data$x)) < 2) {
+          return(data.frame())
+        }
+        if (is.null(data$weight)) data$weight <- 1
+        # figure out x-values
+        if (is.null(xseq)) {
+          if (is.integer(data$x)) {
+            if (fullrange) {
+              xseq <- scales$x$dimension()
             } else {
-              params$se <- TRUE
+              xseq <- sort(unique(data$x))
             }
-            params
-          },
-          compute_group = function(data, scales, formula = y ~ x,
-                                   n = 80, span = 0.75, fullrange = TRUE,
-                                   xseq = NULL, level = 0.95, interval = "confidence",
-                                   lm.args = list(), na.rm = FALSE, se = NULL,
-                                   backtrans = identity
-                                   ) {
+          } else {
+            if (fullrange) {
+              range <- scales$x$dimension()
+            } else {
+              range <- range(data$x, na.rm = TRUE)
+            }
+            xseq <- seq(range[1], range[2], length.out = n)
+          }
+        }
+        base.args <- list(formula = formula, data = quote(data), weights = quote(weight))
+        model <- do.call(stats::lm, c(base.args, lm.args))
+      }
 
-            model <- NULL
-            interval <- match.arg(interval, c("none", "confidence", "prediction"))
-
-            # if no model provided, fit one
-             if (is.null(model)) {
-               # unless we don't have enough data
-               if (length(unique(data$x)) < 2) {
-                 return(data.frame())
-               }
-               if (is.null(data$weight)) data$weight <- 1
-               # figure out x-values
-               if (is.null(xseq)) {
-                 if (is.integer(data$x)) {
-                   if (fullrange) {
-                     xseq <- scales$x$dimension()
-                   } else {
-                     xseq <- sort(unique(data$x))
-                   }
-                 } else {
-                   if (fullrange) {
-                     range <- scales$x$dimension()
-                   } else {
-                     range <- range(data$x, na.rm = TRUE)
-                   }
-                   xseq <- seq(range[1], range[2], length.out = n)
-                 }
-               }
-               base.args <- list(formula = formula, data = quote(data), weights = quote(weight))
-               model <- do.call(stats::lm, c(base.args, lm.args))
-             }
-
-            predictdf(model, xseq = xseq, level = level, interval = interval, se = se, backtrans = backtrans)
-          },
-          required_aes = c("x", "y")
+      predictdf(model, xseq = xseq, level = level, interval = interval, se = se, backtrans = backtrans)
+    },
+    required_aes = c("x", "y")
   )
 
 # modeled after ggplot2:::predictdf.default, but allowing for prediction intervals
 # as well as confidence intervals and always computes SEs.
 
 predictdf <-
-  function (model, xseq, level, interval, se = TRUE, backtrans = identity)
-  {
-    if (! inherits(model, "lm")) {
+  function(model, xseq, level, interval, se = TRUE, backtrans = identity) {
+    if (!inherits(model, "lm")) {
       stop("Model must be created using lm()")
     }
 
     if (interval == "none") interval <- "confidence"
 
     pred <- suppressWarnings(
-      stats::predict(model, newdata = data.frame(x = xseq),
-                     se.fit = TRUE, level = level, interval = interval)
+      stats::predict(model,
+        newdata = data.frame(x = xseq),
+        se.fit = TRUE, level = level, interval = interval
+      )
     )
     fit <- as.data.frame(pred$fit)
     names(fit) <- c("y", "ymin", "ymax")
@@ -486,33 +498,38 @@ predictdf <-
 #'   facet_wrap(~sex)
 #' # non-standard display
 #' ggplot(data = mosaicData::KidsFeet, aes(y = length, x = width, color = sex)) +
-#'   stat_lm(aes(fill = sex), color = NA, interval = "confidence", geom = "ribbon",
-#'   alpha = 0.2) +
+#'   stat_lm(aes(fill = sex),
+#'     color = NA, interval = "confidence", geom = "ribbon",
+#'     alpha = 0.2
+#'   ) +
 #'   geom_point() +
 #'   facet_wrap(~sex)
 #' ggplot(mpg, aes(displ, hwy)) +
-#'   geom_lm(formula = log(y) ~ poly(x,3), backtrans = exp,
-#'      interval = "prediction", fill = "skyblue") +
-#'   geom_lm(formula = log(y) ~ poly(x,3), backtrans = exp, interval = "confidence",
-#'      color = "red") +
+#'   geom_lm(
+#'     formula = log(y) ~ poly(x, 3), backtrans = exp,
+#'     interval = "prediction", fill = "skyblue"
+#'   ) +
+#'   geom_lm(
+#'     formula = log(y) ~ poly(x, 3), backtrans = exp, interval = "confidence",
+#'     color = "red"
+#'   ) +
 #'   geom_point()
-
 geom_lm <-
   function(
-    mapping = NULL, data = NULL, stat = "lm",
-    position = "identity",
-    interval = c("none", "prediction", "confidence"),
-    level = 0.95,
-    formula = y ~ x, lm.args = list(), backtrans = identity,
-    ...,
-    na.rm = FALSE,
-    show.legend = NA,
-    inherit.aes = TRUE)  {
-
-
+             mapping = NULL, data = NULL, stat = "lm",
+             position = "identity",
+             interval = c("none", "prediction", "confidence"),
+             level = 0.95,
+             formula = y ~ x, lm.args = list(), backtrans = identity,
+             ...,
+             na.rm = FALSE,
+             show.legend = NA,
+             inherit.aes = TRUE) {
     interval <- match.arg(interval)
-    params <- list(interval = interval, level = level, formula = formula,
-                   lm.args = lm.args, na.rm = na.rm, backtrans = backtrans, ...)
+    params <- list(
+      interval = interval, level = level, formula = formula,
+      lm.args = lm.args, na.rm = na.rm, backtrans = backtrans, ...
+    )
 
     layer(
       data = data,
@@ -533,28 +550,30 @@ geom_lm <-
 #' @seealso [gf_lm()]
 
 GeomLm <- ggproto("GeomLm", Geom,
-                      setup_data = function(data, params) {
-                        GeomLine$setup_data(data, params)
-                      },
-                      draw_group = function(data, panel_params, coord) {
-                        ribbon <- transform(data, colour = NA)
-                        path <- transform(data, alpha = NA)
+  setup_data = function(data, params) {
+    GeomLine$setup_data(data, params)
+  },
+  draw_group = function(data, panel_params, coord) {
+    ribbon <- transform(data, colour = NA)
+    path <- transform(data, alpha = NA)
 
-                        has_ribbon <- !is.null(data$se_param)  # !is.null(data$ymax) && !is.null(data$ymin)
+    has_ribbon <- !is.null(data$se_param) # !is.null(data$ymax) && !is.null(data$ymin)
 
-                        grid::gList(
-                          if (has_ribbon) GeomRibbon$draw_group(ribbon, panel_params, coord),
-                          GeomLine$draw_panel(path, panel_params, coord)
-                        )
-                      },
+    grid::gList(
+      if (has_ribbon) GeomRibbon$draw_group(ribbon, panel_params, coord),
+      GeomLine$draw_panel(path, panel_params, coord)
+    )
+  },
 
-                      draw_key = draw_key_smooth,
+  draw_key = draw_key_smooth,
 
-                      required_aes = c("x", "y"),
-                      optional_aes = c("ymin", "ymax"),
+  required_aes = c("x", "y"),
+  optional_aes = c("ymin", "ymax"),
 
-                      default_aes = aes(colour = "#3366FF", fill = "grey60", size = 0.7,
-                                        linetype = 1, weight = 1, alpha = 0.3)
+  default_aes = aes(
+    colour = "#3366FF", fill = "grey60", size = 0.7,
+    linetype = 1, weight = 1, alpha = 0.3
+  )
 )
 
 #' ggproto classes for ggplot2
@@ -570,10 +589,10 @@ GeomLm <- ggproto("GeomLm", Geom,
 
 StatAsh <-
   ggproto("StatAsh", Stat,
-          compute_group = function(data, scales, binwidth = NULL, adjust = NULL) {
-            ash_points(data$x, binwidth = binwidth, adjust = adjust)
-          },
-          required_aes = c("x")
+    compute_group = function(data, scales, binwidth = NULL, adjust = NULL) {
+      ash_points(data$x, binwidth = binwidth, adjust = adjust)
+    },
+    required_aes = c("x")
   )
 
 # #' @rdname gf_fitdistr
@@ -601,9 +620,9 @@ StatFitdistr <-
     required_aes = c("x"),
     compute_group =
       function(data, scales, dist = "dnorm", start = NULL,
-               xlim = NULL, n = 101, args = list()) {
+                     xlim = NULL, n = 101, args = list()) {
         # range <- xlim %||% scales$x$dimension()
-        range <- if(is.null(xlim)) scales$x$dimension() else xlim
+        range <- if (is.null(xlim)) scales$x$dimension() else xlim
         xseq <- seq(range[1], range[2], length.out = n)
 
         if (scales$x$is_discrete()) {
@@ -652,15 +671,15 @@ StatFitdistr <-
 
 stat_fitdistr <-
   function(mapping = NULL, data = NULL, geom = "path",
-           position = "identity", na.rm = FALSE, show.legend = NA,
-           inherit.aes = TRUE, dist = "dnorm", start = NULL, ...) {
-#    mapping[["y"]] <- NULL
+             position = "identity", na.rm = FALSE, show.legend = NA,
+             inherit.aes = TRUE, dist = "dnorm", start = NULL, ...) {
+    #    mapping[["y"]] <- NULL
     dist_name <- deparse(substitute(dist))
-    if (! is.character(dist)) dist <- dist_name
+    if (!is.character(dist)) dist <- dist_name
 
     ggplot2::layer(
       stat = StatFitdistr, data = data, mapping = mapping, geom = geom,
       position = position, show.legend = show.legend, inherit.aes = inherit.aes,
       params = list(dist = dist, start = start, ...)
     )
-  }
\ No newline at end of file
+  }
