@@ -88,6 +88,27 @@ test_that(
   }
 )
 
+test_that(
+  "gf_sina()", {
+    set.seed(1234)
+    vdiffr::expect_doppelganger(
+      "gf_sina",
+      gf_sina(Sepal.Length ~ Species, data = iris)
+    )
+    vdiffr::expect_doppelganger(
+      "gf_sina2",
+      gf_sina(Sepal.Length ~ Species, data = iris, color = ~Species)
+    )
+    vdiffr::expect_doppelganger(
+      "gf_sina3",
+      midwest %>%
+        dplyr::mutate(area = cut_number(area, 5)) %>%
+        gf_sina(popdensity ~ area, color = ~area, show.legend = FALSE) %>%
+        gf_refine(scale_y_log10())
+    )
+  }
+)
+
 
 test_that(
   "gf_bar() and gf_col()", {
